Extended Phase-Space Simulations with OpenMM
============================================

[//]: # (Badges)
[![GitHub Actions Build Status](https://github.com/craabreu/openxps/workflows/Linux/badge.svg)](https://github.com/craabreu/openxps/actions?query=workflow%3ALinux)
[![GitHub Actions Build Status](https://github.com/craabreu/openxps/workflows/MacOS/badge.svg)](https://github.com/craabreu/openxps/actions?query=workflow%3AMacOS)
[![GitHub Actions Build Status](https://github.com/craabreu/openxps/workflows/Windows/badge.svg)](https://github.com/craabreu/openxps/actions?query=workflow%3AWindows)
[![GitHub Actions Build Status](https://github.com/craabreu/openxps/workflows/Linter/badge.svg)](https://github.com/craabreu/openxps/actions?query=workflow%3ALinter)
[![Documentation Status](https://github.com/craabreu/openxps/workflows/Docs/badge.svg)](https://github.com/craabreu/openxps/actions?query=workflow%3ADocs)
[![Coverage Report](https://craabreu.github.io/openxps/development/coverage/coverage.svg)](https://craabreu.github.io/openxps/development/coverage)

[![Conda version](https://img.shields.io/conda/v/mdtools/openxps.svg)](https://anaconda.org/mdtools/openxps)
[![Conda platforms](https://img.shields.io/conda/pn/mdtools/openxps.svg)](https://anaconda.org/mdtools/openxps)
[![Conda downloads](https://img.shields.io/conda/dn/mdtools/openxps.svg)](https://anaconda.org/mdtools/openxps)

[![PyPI version](https://img.shields.io/pypi/v/openxps.svg)](https://pypi.org/project/openxps)
[![PyPI version](https://img.shields.io/pypi/pyversions/openxps.svg)](https://pypi.org/project/openxps)
[![PyPI version](https://img.shields.io/pypi/dm/openxps.svg)](https://pypi.org/project/openxps)

[![License](https://img.shields.io/badge/License-MIT-yellowgreen.svg?style=flat)](https://github.com/craabreu/openxps/blob/main/LICENSE.md)

### Overview


### Installation and Usage

OpenXPS is available as a conda package on the [mdtools] channel. To install it, run:

```bash
    conda install -c conda-forge -c mdtools openxps
```

Or:

```bash
    mamba install -c mdtools openxps
```

To use OpenXPS in your own Python script or Jupyter notebook, simply import it as follows:

```python
    import openxps
```

### Documentation

Documentation for the latest OpenXPS version is available at [Github Pages].

### Copyright

Copyright (c) 2024 [C. Abreu](https://github.com/craabreu)


[Github Pages]: https://craabreu.github.io/openxps/latest
[mdtools]: https://anaconda.org/mdtools/openxps
